ANY = "Any"
BCSVF = "bimcollabsmartviewfile"
VERSION = "version"
APPVER = "applicationversion"
SMVSETS = "SMARTVIEWSETS"
SMVSET = "SMARTVIEWSET"
TITLE = "TITLE"
DESCRIPTION = "DESCRIPTION"
GUID = "GUID"
MODDATE = "MODIFICATIONDATE"
SVIEWS = "SMARTVIEWS"
SVIEW = "SMARTVIEW"
CREATOR = "CREATOR"
CREATIONDATE = "CREATIONDATE"
MODIFIER = "MODIFIER"
MODIFICATIONDATE = "MODIFICATIONDATE"
RULES = "RULES"
RULE = "RULE"
ITAKEOFF = "INFORMATIONTAKEOFF"
ITAOPSET = "NFORMATIONTAKEOFF.PROPERTYSETNAME"
ITAOPN = "INFORMATIONTAKEOFF.PROPERTYNAME"
ITAOPER = "INFORMATIONTAKEOFF.OPERATION"
IFCTYPE = "IFCTYPE"
NAME = "NAME"
PSETNAME = "PROPERTYSETNAME"
TYPE = "TYPE"
VALUETYPE = "VALUETYPE"
UNIT = "UNIT"
CONDITION = "CONDITION"
STATE = "STATE"
VALUE = "VALUE"
PROPERTY = "PROPERTY"
PROPERTYSET = "PropertySet"
NONE = "None"
