NS_XSI = "{http://www.w3.org/2001/XMLSchema-instance}"
NS_XS = "{http://www.w3.org/2001/XMLSchema}"
# Classes
ALL = NS_XS + 'all'
ANNOTATED = NS_XS + 'annotated'
ANNOTATION = NS_XS + 'annotation'
ANY = NS_XS + 'any'
ANYATTRIBUTE = NS_XS + 'anyAttribute'
ANYTYPE = NS_XS + 'anyType'
APPINFO = NS_XS + 'appinfo'
ATTRIBUTE = NS_XS + 'attribute'
ATTRIBUTEGROUP = NS_XS + 'attributeGroup'
ATTRIBUTEGROUPREF = NS_XS + 'attributeGroupRef'
CHOICE = NS_XS + 'choice'
COMPLEXCONTENT = NS_XS + 'complexContent'
COMPLEXRESTRICTIONTYPE = NS_XS + 'complexRestrictionType'
COMPLEXTYPE = NS_XS + 'complexType'
DOCUMENTATION = NS_XS + 'documentation'
ELEMENT = NS_XS + 'element'
ENUMERATION = NS_XS + 'enumeration'
EXPLICITGROUP = NS_XS + 'explicitGroup'
EXTENSION = NS_XS + 'extension'
EXTENSIONTYPE = NS_XS + 'extensionType'
FACET = NS_XS + 'facet'
FIELD = NS_XS + 'field'
FRACTIONDIGITS = NS_XS + 'fractionDigits'
GROUP = NS_XS + 'group'
GROUPREF = NS_XS + 'groupRef'
IMPORT = NS_XS + 'import'
INCLUDE = NS_XS + 'include'
KEY = NS_XS + 'key'
KEYBASE = NS_XS + 'keybase'
KEYREF = NS_XS + 'keyref'
LENGTH = NS_XS + 'length'
LIST = NS_XS + 'list'
LOCALCOMPLEXTYPE = NS_XS + 'localComplexType'
LOCALELEMENT = NS_XS + 'localElement'
LOCALSIMPLETYPE = NS_XS + 'localSimpleType'
MAXEXCLUSIVE = NS_XS + 'maxExclusive'
MAXINCLUSIVE = NS_XS + 'maxInclusive'
MAXLENGTH = NS_XS + 'maxLength'
MINEXCLUSIVE = NS_XS + 'minExclusive'
MININCLUSIVE = NS_XS + 'minInclusive'
MINLENGTH = NS_XS + 'minLength'
NAMEDATTRIBUTEGROUP = NS_XS + 'namedAttributeGroup'
NAMEDGROUP = NS_XS + 'namedGroup'
NARROWMAXMIN = NS_XS + 'narrowMaxMin'
NOFIXEDFACET = NS_XS + 'noFixedFacet'
NOTATION = NS_XS + 'notation'
NUMFACET = NS_XS + 'numFacet'
OPENATTRS = NS_XS + 'openAttrs'
PATTERN = NS_XS + 'pattern'
REALGROUP = NS_XS + 'realGroup'
REDEFINE = NS_XS + 'redefine'
RESTRICTION = NS_XS + 'restriction'
RESTRICTIONTYPE = NS_XS + 'restrictionType'
SCHEMA = NS_XS + 'schema'
SELECTOR = NS_XS + 'selector'
SEQUENCE = NS_XS + 'sequence'
SIMPLECONTENT = NS_XS + 'simpleContent'
SIMPLEEXPLICITGROUP = NS_XS + 'simpleExplicitGroup'
SIMPLEEXTENSIONTYPE = NS_XS + 'simpleExtensionType'
SIMPLERESTRICTIONTYPE = NS_XS + 'simpleRestrictionType'
SIMPLETYPE = NS_XS + 'simpleType'
TOPLEVELATTRIBUTE = NS_XS + 'topLevelAttribute'
TOPLEVELCOMPLEXTYPE = NS_XS + 'topLevelComplexType'
TOPLEVELELEMENT = NS_XS + 'topLevelElement'
TOPLEVELSIMPLETYPE = NS_XS + 'topLevelSimpleType'
TOTALDIGITS = NS_XS + 'totalDigits'
UNION = NS_XS + 'union'
UNIQUE = NS_XS + 'unique'
WHITESPACE = NS_XS + 'whiteSpace'
WILDCARD = NS_XS + 'wildcard'

# Attributes
ABSTRACT = 'abstract'
ATTRIBUTEFORMDEFAULT = 'attributeFormDefault'
BASE = 'base'
BLOCK = 'block'
BLOCKDEFAULT = 'blockDefault'
DEFAULT = 'default'
ELEMENTFORMDEFAULT = 'elementFormDefault'
FINAL = 'final'
FINALDEFAULT = 'finalDefault'
FIXED = 'fixed'
FORM = 'form'
ID = 'id'
ITEMTYPE = 'itemType'
MAXOCCURS = 'maxOccurs'
MEMBERTYPES = 'memberTypes'
MINOCCURS = 'minOccurs'
MIXED = 'mixed'
NAME = 'name'
NAMESPACE = 'namespace'
NILLABLE = 'nillable'
PROCESSCONTENTS = 'processContents'
PUBLIC = 'public'
REF = 'ref'
REFER = 'refer'
SCHEMALOCATION = 'schemaLocation'
SOURCE = 'source'
SUBSTITUTIONGROUP = 'substitutionGroup'
SYSTEM = 'system'
TARGETNAMESPACE = 'targetNamespace'
TYPE = 'type'
USE = 'use'
VALUE = 'value'
VERSION = 'version'
XPATH = 'xpath'

# Values
VAL_0 = '0'
VAL_1 = '1'
VAL_COLLAPSE = 'collapse'
VAL_EXTENSION = 'extension'
VAL_LAX = 'lax'
VAL_LIST = 'list'
VAL_OPTIONAL = 'optional'
VAL_PRESERVE = 'preserve'
VAL_PROHIBITED = 'prohibited'
VAL_QUALIFIED = 'qualified'
VAL_REPLACE = 'replace'
VAL_REQUIRED = 'required'
VAL_RESTRICTION = 'restriction'
VAL_SKIP = 'skip'
VAL_STRICT = 'strict'
VAL_SUBSTITUTION = 'substitution'
VAL_UNBOUNDED = 'unbounded'
VAL_UNION = 'union'
VAL_UNQUALIFIED = 'unqualified'

