from .classes import PropertySet, Object, Project, Attribute
from .external_software import desite, excel, allplan, revit, vestra, card1
from .constants import json_constants, value_constants
from .tools import merge_projects

__version__ = "1.6.11"
active_project = None
