ABSORBEDDOSEMEASURE = 'IfcAbsorbedDoseMeasure'
ACCELERATIONMEASURE = 'IfcAccelerationMeasure'
AMOUNTOFSUBSTANCEMEASURE = 'IfcAmountOfSubstanceMeasure'
ANGULARVELOCITYMEASURE = 'IfcAngularVelocityMeasure'
ARCINDEX = 'IfcArcIndex'
AREADENSITYMEASURE = 'IfcAreaDensityMeasure'
AREAMEASURE = 'IfcAreaMeasure'
BINARY = 'IfcBinary'
BOOLEAN = 'IfcBoolean'
BOXALIGNMENT = 'IfcBoxAlignment'
CARDINALPOINTREFERENCE = 'IfcCardinalPointReference'
COMPLEXNUMBER = 'IfcComplexNumber'
COMPOUNDPLANEANGLEMEASURE = 'IfcCompoundPlaneAngleMeasure'
CONTEXTDEPENDENTMEASURE = 'IfcContextDependentMeasure'
COUNTMEASURE = 'IfcCountMeasure'
CURVATUREMEASURE = 'IfcCurvatureMeasure'
DATE = 'IfcDate'
DATETIME = 'IfcDateTime'
DAYINMONTHNUMBER = 'IfcDayInMonthNumber'
DAYINWEEKNUMBER = 'IfcDayInWeekNumber'
DESCRIPTIVEMEASURE = 'IfcDescriptiveMeasure'
DIMENSIONCOUNT = 'IfcDimensionCount'
DOSEEQUIVALENTMEASURE = 'IfcDoseEquivalentMeasure'
DURATION = 'IfcDuration'
DYNAMICVISCOSITYMEASURE = 'IfcDynamicViscosityMeasure'
ELECTRICCAPACITANCEMEASURE = 'IfcElectricCapacitanceMeasure'
ELECTRICCHARGEMEASURE = 'IfcElectricChargeMeasure'
ELECTRICCONDUCTANCEMEASURE = 'IfcElectricConductanceMeasure'
ELECTRICCURRENTMEASURE = 'IfcElectricCurrentMeasure'
ELECTRICRESISTANCEMEASURE = 'IfcElectricResistanceMeasure'
ELECTRICVOLTAGEMEASURE = 'IfcElectricVoltageMeasure'
ENERGYMEASURE = 'IfcEnergyMeasure'
FONTSTYLE = 'IfcFontStyle'
FONTVARIANT = 'IfcFontVariant'
FONTWEIGHT = 'IfcFontWeight'
FORCEMEASURE = 'IfcForceMeasure'
FREQUENCYMEASURE = 'IfcFrequencyMeasure'
GLOBALLYUNIQUEID = 'IfcGloballyUniqueId'
HEATFLUXDENSITYMEASURE = 'IfcHeatFluxDensityMeasure'
HEATINGVALUEMEASURE = 'IfcHeatingValueMeasure'
IDENTIFIER = 'IfcIdentifier'
ILLUMINANCEMEASURE = 'IfcIlluminanceMeasure'
INDUCTANCEMEASURE = 'IfcInductanceMeasure'
INTEGER = 'IfcInteger'
INTEGERCOUNTRATEMEASURE = 'IfcIntegerCountRateMeasure'
IONCONCENTRATIONMEASURE = 'IfcIonConcentrationMeasure'
ISOTHERMALMOISTURECAPACITYMEASURE = 'IfcIsothermalMoistureCapacityMeasure'
KINEMATICVISCOSITYMEASURE = 'IfcKinematicViscosityMeasure'
LABEL = 'IfcLabel'
LANGUAGEID = 'IfcLanguageId'
LENGTHMEASURE = 'IfcLengthMeasure'
LINEARFORCEMEASURE = 'IfcLinearForceMeasure'
LINEARMOMENTMEASURE = 'IfcLinearMomentMeasure'
LINEARSTIFFNESSMEASURE = 'IfcLinearStiffnessMeasure'
LINEARVELOCITYMEASURE = 'IfcLinearVelocityMeasure'
LINEINDEX = 'IfcLineIndex'
LOGICAL = 'IfcLogical'
LUMINOUSFLUXMEASURE = 'IfcLuminousFluxMeasure'
LUMINOUSINTENSITYDISTRIBUTIONMEASURE = 'IfcLuminousIntensityDistributionMeasure'
LUMINOUSINTENSITYMEASURE = 'IfcLuminousIntensityMeasure'
MAGNETICFLUXDENSITYMEASURE = 'IfcMagneticFluxDensityMeasure'
MAGNETICFLUXMEASURE = 'IfcMagneticFluxMeasure'
MASSDENSITYMEASURE = 'IfcMassDensityMeasure'
MASSFLOWRATEMEASURE = 'IfcMassFlowRateMeasure'
MASSMEASURE = 'IfcMassMeasure'
MASSPERLENGTHMEASURE = 'IfcMassPerLengthMeasure'
MODULUSOFELASTICITYMEASURE = 'IfcModulusOfElasticityMeasure'
MODULUSOFLINEARSUBGRADEREACTIONMEASURE = 'IfcModulusOfLinearSubgradeReactionMeasure'
MODULUSOFROTATIONALSUBGRADEREACTIONMEASURE = 'IfcModulusOfRotationalSubgradeReactionMeasure'
MODULUSOFSUBGRADEREACTIONMEASURE = 'IfcModulusOfSubgradeReactionMeasure'
MOISTUREDIFFUSIVITYMEASURE = 'IfcMoistureDiffusivityMeasure'
MOLECULARWEIGHTMEASURE = 'IfcMolecularWeightMeasure'
MOMENTOFINERTIAMEASURE = 'IfcMomentOfInertiaMeasure'
MONETARYMEASURE = 'IfcMonetaryMeasure'
MONTHINYEARNUMBER = 'IfcMonthInYearNumber'
NONNEGATIVELENGTHMEASURE = 'IfcNonNegativeLengthMeasure'
NORMALISEDRATIOMEASURE = 'IfcNormalisedRatioMeasure'
NUMERICMEASURE = 'IfcNumericMeasure'
PARAMETERVALUE = 'IfcParameterValue'
PHMEASURE = 'IfcPHMeasure'
PLANARFORCEMEASURE = 'IfcPlanarForceMeasure'
PLANEANGLEMEASURE = 'IfcPlaneAngleMeasure'
POSITIVEINTEGER = 'IfcPositiveInteger'
POSITIVELENGTHMEASURE = 'IfcPositiveLengthMeasure'
POSITIVEPLANEANGLEMEASURE = 'IfcPositivePlaneAngleMeasure'
POSITIVERATIOMEASURE = 'IfcPositiveRatioMeasure'
POWERMEASURE = 'IfcPowerMeasure'
PRESENTABLETEXT = 'IfcPresentableText'
PRESSUREMEASURE = 'IfcPressureMeasure'
PROPERTYSETDEFINITIONSET = 'IfcPropertySetDefinitionSet'
RADIOACTIVITYMEASURE = 'IfcRadioActivityMeasure'
RATIOMEASURE = 'IfcRatioMeasure'
REAL = 'IfcReal'
ROTATIONALFREQUENCYMEASURE = 'IfcRotationalFrequencyMeasure'
ROTATIONALMASSMEASURE = 'IfcRotationalMassMeasure'
ROTATIONALSTIFFNESSMEASURE = 'IfcRotationalStiffnessMeasure'
SECTIONALAREAINTEGRALMEASURE = 'IfcSectionalAreaIntegralMeasure'
SECTIONMODULUSMEASURE = 'IfcSectionModulusMeasure'
SHEARMODULUSMEASURE = 'IfcShearModulusMeasure'
SOLIDANGLEMEASURE = 'IfcSolidAngleMeasure'
SOUNDPOWERLEVELMEASURE = 'IfcSoundPowerLevelMeasure'
SOUNDPOWERMEASURE = 'IfcSoundPowerMeasure'
SOUNDPRESSURELEVELMEASURE = 'IfcSoundPressureLevelMeasure'
SOUNDPRESSUREMEASURE = 'IfcSoundPressureMeasure'
SPECIFICHEATCAPACITYMEASURE = 'IfcSpecificHeatCapacityMeasure'
SPECULAREXPONENT = 'IfcSpecularExponent'
SPECULARROUGHNESS = 'IfcSpecularRoughness'
TEMPERATUREGRADIENTMEASURE = 'IfcTemperatureGradientMeasure'
TEMPERATURERATEOFCHANGEMEASURE = 'IfcTemperatureRateOfChangeMeasure'
TEXT = 'IfcText'
TEXTALIGNMENT = 'IfcTextAlignment'
TEXTDECORATION = 'IfcTextDecoration'
TEXTFONTNAME = 'IfcTextFontName'
TEXTTRANSFORMATION = 'IfcTextTransformation'
THERMALADMITTANCEMEASURE = 'IfcThermalAdmittanceMeasure'
THERMALCONDUCTIVITYMEASURE = 'IfcThermalConductivityMeasure'
THERMALEXPANSIONCOEFFICIENTMEASURE = 'IfcThermalExpansionCoefficientMeasure'
THERMALRESISTANCEMEASURE = 'IfcThermalResistanceMeasure'
THERMALTRANSMITTANCEMEASURE = 'IfcThermalTransmittanceMeasure'
THERMODYNAMICTEMPERATUREMEASURE = 'IfcThermodynamicTemperatureMeasure'
TIME = 'IfcTime'
TIMEMEASURE = 'IfcTimeMeasure'
TIMESTAMP = 'IfcTimeStamp'
TORQUEMEASURE = 'IfcTorqueMeasure'
URIREFERENCE = 'IfcURIReference'
VAPORPERMEABILITYMEASURE = 'IfcVaporPermeabilityMeasure'
VOLUMEMEASURE = 'IfcVolumeMeasure'
VOLUMETRICFLOWRATEMEASURE = 'IfcVolumetricFlowRateMeasure'
WARPINGCONSTANTMEASURE = 'IfcWarpingConstantMeasure'
WARPINGMOMENTMEASURE = 'IfcWarpingMomentMeasure'